@@ -4,24 +4,25 @@
 # Purpose: plots
 
 #' Plots the model implied effect of 1 predictor for one outcome 
-#' @param x mvtb output object
+#' @param x \code{mvtb} output object
 #' @param predictor.no index of the predictor variable
 #' @param response.no index of the response variable
-#' @param n.trees desired number of trees (default: best trees)
-#' @param X predictor. If included, a rug is included with the plot showing the density of the variable.
+#' @param n.trees desired number of trees. Defaults to the minimum number of trees by CV, test, or training error
+#' @param X optional vector, matrix, or data.frame of predictors. If included, a 'rug' (a small vertical line for each observation) is plotted on the x-axis showing the density of \code{predictor.no}. 
 #' @param xlab label of the x axis
 #' @param ylab label of the y axis
-#' @param ... extra arguments are passed to plot. See ?par
-#' @return Function does not return a value, but produces a plot of the model implied effect along with the relative influence of the predictor.
+#' @param return.grid \code{TRUE/FALSE} return the prediction grid from \code{gbm}. Default is \code{FALSE}.
+#' @param ... extra arguments are passed to plot. See \code{?par}
+#' @return Produces a plot of the model implied effect along with the relative influence of the predictor. If \code{return.grid=TRUE}, returns the plotting matrix as well.
 #' @seealso \code{plot.gbm}, \code{mvtb.perspec}, for other plots, \code{mvtb.heat} to plot the covariance explained by predictors in a heatmap
 #' @export
 #' @importFrom graphics plot rug
 #' @details 
 #' This is the classic partial dependence plot, where the model implied effect of the chosen predictor is plotted
 #' controlling for the other predictors. In addition to the model-implied effect, the relative influence
-#' of the predictor is included in the x-axis label. If this is not desired, a custom xlabel can be provided.
+#' of the predictor is included in the x-axis label. If this is not desired, a custom label can be provided via \code{xlab}.
 #' 
-plot.mvtb <- function(x,predictor.no=1,response.no=1,n.trees=NULL,X=NULL,xlab=NULL,ylab=NULL,...){
+plot.mvtb <- function(x,predictor.no=1,response.no=1,n.trees=NULL,X=NULL,xlab=NULL,ylab=NULL,return.grid=FALSE,...){
   if(any(unlist(lapply(x,function(li){is.raw(li)})))){
     x <- mvtb.uncomp(x)
   }
@@ -35,8 +36,12 @@ plot.mvtb <- function(x,predictor.no=1,response.no=1,n.trees=NULL,X=NULL,xlab=NU
   }
   if(is.null(ylab)) { ylab <- x$ynames[response.no]}
   grid <- gbm::plot.gbm(gbm.obj,i.var = predictor.no,n.trees = n.trees,perspective=TRUE,return.grid=TRUE)  
-  plot(y=grid$y,x=grid[,1],type="l",bty="n",xlab=xlab,ylab=ylab,...)
-  if(!is.null(X)) { rug(jitter(X[,predictor.no])) }
+  if(return.grid==FALSE){
+    plot(y=grid$y,x=grid[,1],type="l",bty="n",xlab=xlab,ylab=ylab,...)
+    if(!is.null(X)) { rug(jitter(X[,predictor.no])) }
+  } else {
+    return(grid)
+  }
 }
 
 
@@ -45,21 +50,21 @@ plot.mvtb <- function(x,predictor.no=1,response.no=1,n.trees=NULL,X=NULL,xlab=NU
 #' This is a plot of the model implied function of 2 predictors averaged over the other predictors
 #' included in the model. This is called a partial dependence plot.
 #' As an alternative to the perspective (3D) plot, a 2D heat plot can be obtained directly
-#' using ?plot.gbm.
+#' using \code{?plot.gbm}.
 #' 
-#' @param object mvtb output object
+#' @param object \code{mvtb} output object
 #' @param response.no index of the response variable
 #' @param predictor.no vector containing indices of the predictor variables to plot
-#' @param n.trees desired number of trees (default: best trees)
-#' @param phi angle of viewing direction. See ?persp.
-#' @param theta angle of viewing direction See ?persp.
-#' @param r distance from eye to center. See ?persp
-#' @param d strength of perspective. See ?persp. 
-#' @param ticktype 'detailed' gives axis points. See ?persp for other options.
+#' @param n.trees desired number of trees. Defaults to the minimum number of trees by CV, test, or training error
+#' @param phi angle of viewing direction. See \code{?persp}.
+#' @param theta angle of viewing direction See \code{?persp}.
+#' @param r distance from eye to center. See \code{?persp}.
+#' @param d strength of perspective. See \code{?persp}.
+#' @param ticktype 'detailed' gives axis points. See \code{?persp} for other options.
 #' @param xlab, title for x axis, must be character strings. 
 #' @param ylab, title for y axis, must be character strings.  
 #' @param zlab, title for z axis, must be character strings. 
-#' @param ... extra arguments are passed to persp. See ?persp
+#' @param ... extra arguments are passed to persp. See \code{?persp}
 #' @return Function returns a plot.
 #' @seealso \code{plot.gbm}, \code{plot.mvtb}, \code{mvtb.heat}
 #' @export
@@ -109,22 +114,25 @@ plot.pw.perspec <- function(out,response.no,predictor.no,npairs=3,nonlin.rank=NU
   }
 }
 
-#' Simple (clustered) heatmap of tables from mvtb (relative influence, covariance explained)
+#' Clustered heatmap of tables from \code{mvtb}
 #' 
-#' @param x Any table. For example: the covariance explained (\code{res$covex}), or relative influence \code{mvtb.ri(res)}
-#' @param clust.method clustering method for rows and columns. See ?hclust. If NULL, unclustered.
-#' @param dist.method  method for computing the distance between columns See ?dist for alternatives.
-#' @param numformat function to format the covex values into strings. Defaults to removing leading 0 and rounding to 2 decimal places.
+#' Simple (clustered) heatmap of tables from \code{mvtb} (relative influence, covariance explained)
+#' 
+#' @param x Any table. For example: the covariance explained (\code{res$covex}), or relative influence \code{mvtb.ri(res)}. If \code{x} is an \code{mvtb} object, defaults to \code{mvtb.covex(x)}
+#' @param clust.method clustering method for rows and columns. This should be (an unambiguous abbreviation of) one of \code{"ward.D"}, \code{"ward.D2"}, \code{"single"}, \code{"complete"}, \code{"average"} (= UPGMA), \code{"mcquitty"} (= WPGMA), \code{"median"} (= WPGMC) or \code{"centroid"} (= UPGMC). If \code{NULL}, unclustered.
+#' @param dist.method  method for computing the distance between two lower triangular covariance matrices. This must be one of \code{"euclidean"}, \code{"maximum"}, \code{"manhattan"}, \code{"canberra"}, \code{"binary"} or \code{"minkowski"}. Any unambiguous substring can be given.
+#' @param numformat function to format the covex values into strings. Defaults to removing leading 0 and rounding to \code{dec = 2} decimal places.
+#' @param dec Number of decimal places to round to if \code{numformat} is unspecified. Defaults to 2.
 #' @param col A list of colors mapping onto covex explained values. A white to black gradient is default.
 #' @param cexRow, See \code{cex.axis} from par. The magnification used for the row axis labels. A useful default is provided.
 #' @param cexCol, See \code{cex.axis} from par. The magnification used for the col axis labels. The default is set equal to the row axis labels.
 #' @param ... extra arguments are passed to image, then to plot. See ?image, ?par
-#' @return heatmap of x, usually a covariance explained matrix or a matrix of (relative) influences.
+#' @return heatmap of \code{x}, usually a covariance explained matrix or a matrix of (relative) influences.
 #' @details You will probably want to modify the default colors.
 #' @export 
 #' @seealso \code{plot.mvtb}, \code{mvtb.perspec}
 #' @importFrom graphics image axis text
-mvtb.heat <- function(x,clust.method="ward.D",dist.method="manhattan",numformat=NULL,col=NULL,cexRow=NULL,cexCol=NULL,...) {
+mvtb.heat <- function(x,clust.method="ward.D",dist.method="manhattan",dec=2,numformat=NULL,col=NULL,cexRow=NULL,cexCol=NULL,...) {
   if(class(x) %in% "mvtb"){
     if(any(unlist(lapply(x,function(li){is.raw(li)})))){
       x <- mvtb.uncomp(x)
@@ -134,7 +142,9 @@ mvtb.heat <- function(x,clust.method="ward.D",dist.method="manhattan",numformat=
   if(!is.null(clust.method)){
     x <- mvtb.cluster(x,clust.method=clust.method,dist.method=dist.method)
   }
-  if(is.null(numformat)){ numformat <- function(val){sub("^(-?)0.", "\\1.", sprintf("%.2f", val))}}
+  if(is.null(numformat)){ 
+    numformat <- function(val){sub("^(-?)0.", "\\1.", sprintf(paste0("%.",dec,"f"), val))}
+  }
   cellnote <- matrix(numformat(x),dim(x))
   #cellnote <- cellnote[rowInd,colInd] DONT BE TEMPTED TO DO THIS
   x <- t(x)
